# pyscenarios

Python Monte Carlo Scenario Generator

Full documentation at http://pyscenarios.readthedocs.io/

[![docs-badge](https://github.com/crusaderky/pyscenarios/actions/workflows/docs.yml/badge.svg)](https://github.com/crusaderky/pyscenarios/actions)
[![lint-badge](https://github.com/crusaderky/pyscenarios/actions/workflows/pre-commit.yml/badge.svg)](https://github.com/crusaderky/pyscenarios/actions)
[![pytest-badge](https://github.com/crusaderky/pyscenarios/actions/workflows/pytest.yml/badge.svg)](https://github.com/crusaderky/pyscenarios/actions)
[![codecov-badge](https://codecov.io/gh/crusaderky/pyscenarios/branch/main/graph/badge.svg)](https://codecov.io/gh/crusaderky/pyscenarios/branch/main)
